SetIgnored

difflicious.ConfigureOp.SetIgnored
final case class SetIgnored(isIgnored: Boolean) extends ConfigureOp

Attributes

Graph
Supertypes
trait Serializable
trait Product
trait Equals
trait ConfigureOp
class Object
trait Matchable
class Any
Show all

Members list

Value members

Inherited methods

def productElementNames: Iterator[String]

An iterator over the names of all the elements of this product.

An iterator over the names of all the elements of this product.

Attributes

Inherited from:
Product
def productIterator: Iterator[Any]

An iterator over all the elements of this product.

An iterator over all the elements of this product.

Attributes

Returns

in the default implementation, an Iterator[Any]

Inherited from:
Product