ObtainedOnly

difflicious.DiffResult.ValueResult.ObtainedOnly
final case class ObtainedOnly(obtained: String, isIgnored: Boolean) extends ValueResult

Attributes

Graph
Supertypes
trait Serializable
trait Product
trait Equals
trait ValueResult
trait DiffResult
class Object
trait Matchable
class Any
Show all

Members list

Value members

Concrete methods

override def isOk: Boolean

Whether this DiffResult is consider "successful". If there are any non-ignored differences found, then this should be false

Whether this DiffResult is consider "successful". If there are any non-ignored differences found, then this should be false

Attributes

Definition Classes
override def pairType: PairType

Whether the input leading to this DiffResult has both sides or just one.

Whether the input leading to this DiffResult has both sides or just one.

Attributes

Definition Classes

Inherited methods

def productElementNames: Iterator[String]

An iterator over the names of all the elements of this product.

An iterator over the names of all the elements of this product.

Attributes

Inherited from:
Product
def productIterator: Iterator[Any]

An iterator over all the elements of this product.

An iterator over all the elements of this product.

Attributes

Returns

in the default implementation, an Iterator[Any]

Inherited from:
Product