Case

difflicious.differ.OneOfDiffer.Case
final case class Case[A, B](typeName: SomeTypeName, extract: A => Option[B], differ: Differ[B])

A single possible case in a OneOfDiffer.

A typeName is required because we want to provide an alternative name. For example, a JSON array may be stored/compared as a List, but we want to call it JsonArray

Attributes

Graph
Supertypes
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all

Members list

Value members

Concrete methods

def id: String

Inherited methods

def productElementNames: Iterator[String]

An iterator over the names of all the elements of this product.

An iterator over the names of all the elements of this product.

Attributes

Inherited from:
Product
def productIterator: Iterator[Any]

An iterator over all the elements of this product.

An iterator over all the elements of this product.

Attributes

Returns

in the default implementation, an Iterator[Any]

Inherited from:
Product