difflicious.DiffResult.ValueResult.ObtainedOnly
Attributes
-
Graph
-
-
Supertypes
-
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all
Members list
Whether this DiffResult is consider "successful". If there are any non-ignored differences found, then this should be false
Whether this DiffResult is consider "successful". If there are any non-ignored differences found, then this should be false
Attributes
-
Definition Classes
-
Whether the input leading to this DiffResult has both sides or just one.
Whether the input leading to this DiffResult has both sides or just one.
Attributes
-
Definition Classes
-
An iterator over the names of all the elements of this product.
An iterator over the names of all the elements of this product.
Attributes
-
Inherited from:
-
Product
An iterator over all the elements of this product.
An iterator over all the elements of this product.
Attributes
-
Returns
-
in the default implementation, an Iterator[Any]
-
Inherited from:
-
Product