Case
difflicious.differ.OneOfDiffer.Case
A single possible case in a OneOfDiffer.
A typeName is required because we want to provide an alternative name. For example, a JSON array may be stored/compared as a List, but we want to call it JsonArray
Attributes
- Graph
-
- Supertypes
-
trait Serializabletrait Producttrait Equalsclass Objecttrait Matchableclass Any
Members list
In this article